@@ -16,7 +16,7 @@
 #'   `var1`).
 #' @param label.expression An expression evaluating to a logical vector that
 #'   determines the subset of data points to label (e.g. `y < 4 & z < 20`).
-#'   While using this argument with `purrr::pmap`, you will have to provide a
+#'   While using this argument with `purrr::pmap()`, you will have to provide a
 #'   quoted expression  (e.g. `quote(y < 4 & z < 20)`).
 #' @param point.label.args A list of additional aesthetic arguments to be passed
 #'   to `ggrepel::geom_label_repel` geom used to display the labels.
@@ -34,7 +34,7 @@
 #'   displaying the **points** and the other displaying the ***labels** for
 #'   these points.
 #' @param xsidehistogram.args,ysidehistogram.args A list of arguments passed to
-#'   respective `geom_`s from `ggside` package to change the marginal
+#'   respective `geom_`s from the `{ggside}` package to change the marginal
 #'   distribution histograms plots.
 #' @inheritParams statsExpressions::corr_test
 #' @inheritParams theme_ggstatsplot
@@ -69,7 +69,6 @@
 #' ) +
 #'   ggplot2::geom_rug(sides = "b")
 #'
-#'
 #' # looking at the plot
 #' p
 #'
@@ -95,8 +94,8 @@ ggscatterstats <- function(data,
                            point.height.jitter = 0,
                            point.label.args = list(size = 3, max.overlaps = 1e6),
                            smooth.line.args = list(linewidth = 1.5, color = "blue", method = "lm", formula = y ~ x),
-                           xsidehistogram.args = list(fill = "#009E73", color = "black"),
-                           ysidehistogram.args = list(fill = "#D55E00", color = "black"),
+                           xsidehistogram.args = list(fill = "#009E73", color = "black", na.rm = TRUE),
+                           ysidehistogram.args = list(fill = "#D55E00", color = "black", na.rm = TRUE),
                            xlab = NULL,
                            ylab = NULL,
                            title = NULL,
@@ -185,7 +184,7 @@ ggscatterstats <- function(data,
 
   # marginal  ---------------------------------------------
 
-  if (marginal) {
+  if (isTRUE(marginal)) {
     check_if_installed("ggside", minimum_version = "0.2.1")
 
     # adding marginal distributions
@@ -219,8 +218,7 @@ ggscatterstats <- function(data,
 #' @inherit ggscatterstats return references
 #' @inherit ggscatterstats return details
 #'
-#' @examplesIf requireNamespace("ggside", quietly = TRUE)
-#' \donttest{
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("ggside", quietly = TRUE)
 #' # to ensure reproducibility
 #' set.seed(123)
 #'
@@ -260,23 +258,16 @@ ggscatterstats <- function(data,
 #'   label.var       = "title",
 #'   annotation.args = list(tag_levels = "a")
 #' )
-#' }
 #' @export
 grouped_ggscatterstats <- function(data,
                                    ...,
                                    grouping.var,
                                    plotgrid.args = list(),
                                    annotation.args = list()) {
-  # getting the data frame ready
-  data %<>% .grouped_list({{ grouping.var }})
-
-  # creating a list of plots
-  p_ls <- purrr::pmap(
-    .l = list(data = data, title = names(data)),
-    .f = ggstatsplot::ggscatterstats,
+  purrr::pmap(
+    .l = .grouped_list(data, {{ grouping.var }}),
+    .f = ggscatterstats,
     ...
-  )
-
-
-  combine_plots(p_ls, plotgrid.args, annotation.args)
+  ) %>%
+    combine_plots(plotgrid.args, annotation.args)
 }
