@@ -3,7 +3,6 @@
 utils::globalVariables(
   names = c(
     ".",
-    "..count..",
     "N",
     "conf.high",
     "conf.low",
@@ -40,8 +39,7 @@ utils::globalVariables(
     ".f",
     ".fn",
     ".ns",
-    "log_e_bf10",
-    "sort_parameters"
+    "log_e_bf10"
   ),
   package = "ggstatsplot",
   add = FALSE
