@@ -8,10 +8,8 @@
 #' @inheritParams ggbetweenstats
 #' @param grouping.var A single grouping variable.
 #'
-#' @examples
-#' \donttest{
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
 #' ggstatsplot:::.grouped_list(ggplot2::msleep, grouping.var = vore)
-#' }
 #' @keywords internal
 .grouped_list <- function(data, grouping.var = NULL) {
   data <- as_tibble(data)
@@ -20,7 +18,9 @@
     return(data)
   }
 
-  data %>% split(f = new_formula(NULL, enquo(grouping.var)), drop = TRUE)
+  data %>%
+    split(f = new_formula(NULL, enquo(grouping.var)), drop = TRUE) %>%
+    list(data = ., title = names(.))
 }
 
 
@@ -38,7 +38,7 @@
   are_enough_colors_available <- palette_length > min_length
 
   if (!are_enough_colors_available) {
-    rlang::warn(c(
+    rlang::inform(c(
       "Number of labels is greater than default palette color count.",
       "Select another color `palette` (and/or `package`)."
     ))
