@@ -1,5 +1,3 @@
-skip_if(getRversion() < "4.1")
-
 # errors ------------------------------------------
 
 test_that("ggcoefstats doesn't work if no estimate column found", {
@@ -14,25 +12,25 @@ test_that("default plots are rendered correctly for each type of statistic", {
   library(survival)
 
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "t-statistic",
     fig = ggcoefstats(stats::lm(formula = wt ~ am * cyl, data = mtcars))
   )
 
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "F-statistic",
     fig = ggcoefstats(aov(yield ~ N * K, npk))
   )
 
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "F-statistic with omega",
     fig = ggcoefstats(stats::aov(wt ~ mpg * am, mtcars), effectsize.type = "omega")
   )
 
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "chi2-statistic",
     fig = suppressWarnings(ggcoefstats(
       survival::coxph(Surv(time, status) ~ age + sex + frailty(inst), lung)
@@ -49,7 +47,7 @@ test_that("default plots are rendered correctly for each type of statistic", {
   )
 
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "z-statistic",
     fig = ggcoefstats(mod_glm, conf.level = 0.90)
   )
@@ -61,6 +59,7 @@ df_meta <- tibble(
 )
 
 test_that("meta-analysis works", {
+  skip_on_cran()
   skip_if_not_installed("metafor")
   skip_on_os(c("windows", "linux", "solaris"))
 
@@ -75,7 +74,7 @@ test_that("meta-analysis works", {
 
   skip_on_os("mac", c("i386", "x86_64"))
   set.seed(123)
-  vdiffr::expect_doppelganger(
+  expect_doppelganger(
     title = "meta-analysis works",
     fig = p_meta
   )
@@ -90,7 +89,7 @@ test_that(
     mod1 <- stats::lm(data = mtcars, formula = wt ~ mpg * am)
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "plot modifications",
       fig = suppressWarnings(ggcoefstats(
         x = mod1,
@@ -111,7 +110,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "sorting works",
       fig = ggcoefstats(
         x = mod2,
@@ -143,7 +142,7 @@ test_that(
 
     skip_on_os("mac", c("i386", "x86_64"))
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "NAs in numeric columns",
       fig = m_lmer
     )
@@ -157,7 +156,7 @@ test_that(
     df_base <- tidy_model_parameters(stats::lm(wt ~ am * cyl, mtcars))
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "CIs missing",
       fig = ggcoefstats(dplyr::select(df_base, -dplyr::matches("conf")), statistic = "t")
     )
@@ -176,6 +175,7 @@ test_that(
 test_that(
   desc = "meta analysis subtitle and caption",
   code = {
+    skip_on_cran()
     skip_if_not_installed("metafor")
     skip_if_not_installed("metaBMA")
     skip_if_not_installed("metaplus")
