@@ -1,17 +1,16 @@
-skip_if(getRversion() < "4.1")
 skip_if_not_installed("ggcorrplot")
 
 test_that(
   desc = "checking ggcorrmat with entier dataset",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "parametric correlation - without NAs",
       fig = ggcorrmat(anscombe, type = "p")
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "non-parametric correlation - with NAs",
       fig = ggcorrmat(ggplot2::msleep, type = "np")
     )
@@ -36,7 +35,7 @@ test_that(
   desc = "ggcorrmat works as expected with changed defaults",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "changing aesthetic defaults",
       fig = ggcorrmat(
         data = dplyr::select(iris, dplyr::contains("Petal")),
@@ -56,7 +55,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "applying ggplot2 function works",
       fig = ggcorrmat(
         data = dplyr::select(ggplot2::msleep, brainwt, sleep_rem, bodywt),
@@ -72,26 +71,6 @@ test_that(
   }
 )
 
-# checking all data frame outputs -------------------------------------------
-
-test_that(
-  desc = "checking all data frame outputs",
-  code = {
-    options(tibble.width = Inf)
-    skip_if_not(.Platform$OS.type == "unix")
-
-    set.seed(123)
-    expect_snapshot(suppressWarnings(purrr::pmap(
-      .l = list(
-        data = list(dplyr::select(ggplot2::msleep, brainwt, sleep_rem, bodywt)),
-        type = list("p", "p", "np", "np", "r", "r", "bf", "bayes"),
-        output = list("dataframe"),
-        partial = list(TRUE, FALSE, TRUE, FALSE, TRUE, FALSE, TRUE, FALSE)
-      ),
-      .f = ggcorrmat
-    )))
-  }
-)
 
 # grouped_ggcorrmat output: plot ---------------------------------------------------------------
 
@@ -101,7 +80,7 @@ test_that(
   desc = "grouped_ggcorrmat plots are as expected",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "without NAs",
       fig = grouped_ggcorrmat(
         iris,
@@ -111,7 +90,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "with NAs",
       fig = grouped_ggcorrmat(
         data = dplyr::select(ggplot2::msleep, dplyr::matches("sleep|awake|vore")),
@@ -129,23 +108,3 @@ test_that(
     expect_snapshot_error(grouped_ggcorrmat(iris))
   }
 )
-
-# output: data frame ---------------------------------------------------------------
-
-test_that(
-  desc = "grouped_ggcorrmat returns expected data frame",
-  code = {
-    options(tibble.width = Inf)
-
-    # tidy data frame
-    df <- grouped_ggcorrmat(
-      data = dplyr::select(ggplot2::msleep, dplyr::matches("sleep|awake|vore")),
-      grouping.var = vore,
-      type = "r",
-      output = "data"
-    )
-
-    set.seed(123)
-    expect_snapshot(df)
-  }
-)
