@@ -1,18 +1,16 @@
-skip_if(getRversion() < "4.1")
-
 # checking default outputs -----------------------------------------
 
 test_that(
   desc = "checking default outputs",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "parametric - without NA",
       fig = gghistostats(ggplot2::mpg, cty, test.value = 20, type = "p")
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "robust - with NA",
       fig = gghistostats(dplyr::starwars, height, test.value = 150, type = "r")
     )
@@ -25,7 +23,7 @@ test_that(
   desc = "aesthetic modifications work",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "aesthetic modifications work",
       fig = gghistostats(
         data = dplyr::starwars,
@@ -50,7 +48,7 @@ test_that(
   desc = "checking if normal curve work",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "plot normal curve",
       fig = gghistostats(
         data = ggplot2::msleep,
@@ -106,7 +104,7 @@ test_that(
   desc = "grouped_gghistostats plotting works as expected",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "defaults as expected",
       fig = grouped_gghistostats(
         data = ggplot2::msleep,
@@ -117,7 +115,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "modification with ggplot2 works",
       fig = suppressWarnings(grouped_gghistostats(
         data = ggplot2::msleep,
