@@ -1,5 +1,3 @@
-skip_if(getRversion() < "4.1")
-
 # data for paired tests
 set.seed(123)
 survey_data <- dplyr::tibble(
@@ -20,31 +18,31 @@ test_that(
   desc = "checking default outputs",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking one-way table - without NA",
       fig = ggpiestats(mtcars, cyl)
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking one-way table - with NA",
       fig = ggpiestats(ggplot2::msleep, vore)
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking unpaired two-way table - without NA",
       fig = ggpiestats(mtcars, am, cyl)
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking unpaired two-way table - with NA",
       fig = ggpiestats(ggplot2::msleep, conservation, vore)
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking paired two-way table - without NA",
       fig = ggpiestats(survey_data, `1st survey`, `2nd survey`,
         counts = Counts,
@@ -53,10 +51,10 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking paired two-way table - with NA",
       fig = ggpiestats(
-        data = survey_data_NA,
+        survey_data_NA,
         x = `1st survey`,
         y = `2nd survey`,
         counts = Counts,
@@ -72,38 +70,41 @@ test_that(
   desc = "changing labels and aesthetics",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking percentage labels",
       fig = ggpiestats(
-        data = mtcars, x = cyl, label = "percentage",
+        mtcars,
+        x = cyl, label = "percentage",
         results.subtitle = FALSE
       )
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking count labels",
       fig = ggpiestats(
-        data = mtcars, x = cyl, label = "counts",
+        mtcars,
+        x = cyl, label = "counts",
         results.subtitle = FALSE
       )
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "checking percentage and count labels",
       fig = ggpiestats(
-        data = mtcars, x = cyl, label = "both",
+        mtcars,
+        x = cyl, label = "both",
         results.subtitle = FALSE
       )
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "changing aesthetics works",
       fig = suppressWarnings(
         ggpiestats(
-          data = mtcars,
+          mtcars,
           x = am,
           y = cyl,
           perc.k = 2L,
@@ -118,45 +119,11 @@ test_that(
       )
     )
 
-    # data
-    df <- structure(
-      list(
-        epoch = structure(
-          c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L),
-          .Label = c("Before", "After"),
-          class = "factor"
-        ),
-        mode = structure(c(1L, 1L, 2L, 2L, 3L, 3L, 4L, 4L),
-          .Label = c("A", "P", "C", "T"), class = "factor"
-        ),
-        counts = c(30916L, 21117L, 7676L, 1962L, 1663L, 462L, 7221L, 197L),
-        perc = c(
-          65.1192181312663,
-          88.9586317297161,
-          16.1681691802174,
-          8.26522874715646,
-          3.50282247872609,
-          1.94624652455978,
-          15.2097902097902,
-          0.829892998567697
-        ),
-        label = c(
-          "65%", "89%", "16%", "8%",
-          "4%", "2%", "15%", "1%"
-        )
-      ),
-      row.names = c(NA, -8L),
-      class = c("tbl_df", "tbl", "data.frame")
-    )
-
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "label repelling works",
       fig = ggpiestats(
-        df,
-        mode,
-        epoch,
-        counts = counts,
+        mtcars, am, vs,
         label.repel = TRUE,
         results.subtitle = FALSE
       )
@@ -174,13 +141,13 @@ test_that(
 
     # TODO: should one-way table results be shown in the subtitle?
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "works with dropped levels",
       fig = ggpiestats(mtcars_small, cyl, am)
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "prop test fails with dropped levels",
       fig = ggpiestats(mtcars_small, am, cyl)
     )
@@ -194,7 +161,7 @@ test_that(
   code = {
     set.seed(123)
     p_sub <- ggpiestats(
-      data = ggplot2::msleep,
+      ggplot2::msleep,
       x = conservation,
       y = vore,
       k = 4L
@@ -203,7 +170,7 @@ test_that(
 
     set.seed(123)
     stats_output <- suppressWarnings(contingency_table(
-      data = ggplot2::msleep,
+      ggplot2::msleep,
       x = conservation,
       y = vore,
       k = 4L
@@ -226,10 +193,10 @@ test_that(
   desc = "grouped_ggpiestats works",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "grouped_ggpiestats with one-way table",
       fig = grouped_ggpiestats(
-        data = mtcars,
+        mtcars,
         grouping.var = am,
         x = cyl
       )
@@ -245,10 +212,10 @@ test_that(
 
     # when arguments are entered as bare expressions
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "grouped_ggpiestats with two-way table",
       fig = grouped_ggpiestats(
-        data = mpg_short,
+        mpg_short,
         x = cyl,
         y = class,
         grouping.var = drv,
@@ -271,10 +238,10 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "common legend when levels are dropped",
       fig = grouped_ggpiestats(
-        data = df,
+        df,
         x = measurement,
         y = flag,
         grouping.var = dataset,
